@@ -110,7 +110,8 @@ class MicroDisc:
         else:
             print('Error. Either CO or CR should be zero.') 
         self.A = np.pi*a**2
-        self.km = self.sign*4*self.D/(np.pi*self.a)
+        self.m0 = self.sign*4*self.D/(np.pi*self.a)
+        self.km = m0
         self.iLim = n*F*self.A*self.m0*self.C
 
     def LSV(self, E):
@@ -157,6 +158,7 @@ class MicroBand:
     def __init__(self, t=1, n=1, D=1e-5, cb=1e-6, w=5e-4, l=500e-4):
         self.A = w*l
         self.m0 = 2*np.pi*D/(w*log(64*D*t/w**2))
+        self.km = m0
         self.iLim = n*F*self.A*self.m0*cb
 
 
